import { characterListContainsEntityAlike, testCharacterListConsistency, unescapeMarkdown, } from '../@utils';
import { createAutoTransformFeature } from './@auto-transform-feature';
const IMAGE_REGEX = /* /$image-markdown/ */ /(!\[)((?:(?!\])(?:\\[!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-]|(?!\\).|\\(?![!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-])))*)(\]\((((?:(?![\s)])(?:\\[!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-]|(?!\\).|\\(?![!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-])))+)(?: +\d+[wx])?(?:\s*,\s*(?:(?![\s)])(?:\\[!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-]|(?!\\).|\\(?![!"#$%&'()*+,.\/:;<=>?@^_`{}~\[\]\\\-])))+(?: +\d+[wx])?)*)\))$/;
export function createImageFeature() {
    return createAutoTransformFeature({
        matcher(leftText, input) {
            let groups = IMAGE_REGEX.exec(leftText + input);
            if (!groups) {
                return undefined;
            }
            /* /$image-markdown/ */
            let opening = groups[1];
            let altSource = groups[2];
            let closing = groups[3];
            let srcSetSource = groups[4];
            let srcSource = groups[5];
            let { markdown, text: alt } = unescapeMarkdown(altSource);
            let { text: src } = unescapeMarkdown(srcSource);
            let srcSet;
            if (srcSetSource !== srcSource) {
                ({ text: srcSet } = unescapeMarkdown(srcSetSource));
            }
            let atomic = {
                type: 'image',
                alt,
                src,
                srcSet,
            };
            return {
                opening,
                closing,
                markdownFragments: [markdown],
                textFragments: ['\u200b'],
                atomic,
            };
        },
        compatibilityTester(opening, content, closing) {
            let list = [...opening, ...content, ...closing];
            return (testCharacterListConsistency(list) &&
                !characterListContainsEntityAlike(list));
        },
    });
}
//# sourceMappingURL=image-feature.js.map